@@ -3,29 +3,23 @@ use std::io::{Read, Write};
 use std::process::{Command, Stdio};
 use std::thread;
 
-
 mod app;
 
 use app::App;
 
-
 #[derive(FromArgs)]
-// Foo
-#[argh(description = "asd")]
+#[argh(description = "command line enhancement tool")]
 struct Args {
     #[argh(
         switch,
         description = "don't add a carriage return on new lines received from child command's stdout"
     )]
-    //Bar
     no_crlf: bool,
 
-    #[argh(positional, description = "asd")]
-    // foo
+    #[argh(positional, description = "command to run")]
     command: String,
 
-    #[argh(positional, description = "asd")]
-    // foo
+    #[argh(positional, description = "arguments to the command")]
     args: Vec<String>,
 }
 
